---
title: "Appendix"
author: "US EPA's Center for Computational Toxicology and Exposure ccte@epa.gov"
output:
  rmarkdown::html_vignette
bibliography: '`r system.file("REFERENCES.bib", package="invitroTKstats")`'
vignette: >
  %\VignetteIndexEntry{Appendix}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center'
)
```

## Introduction

Throughout the `invitroTKstats` R package, there is standardized notation used to describe the data processing pipeline. This appendix serves as an overview for users to understand the data structure at each processing step. 

The minimum information required to pipeline data through `invitroTKstats` can be found in each of the vignettes titled "\<Assay\>" where "\<Assay\>" can be replaced with the following assays represented in the `invitroTKstats` package:

- "Clint": intrinsic hepatic clearance $Cl_{int}$
- "Fup RED": fraction unbound in plasma $f_{up}$ via Rapid Equilibrium Dialysis (RED)
- "Fup UC": fraction unbound in plasma $f_{up}$ via Ultracentrifugation (UC)
- "Caco2": membrane permeability $P_{app}$ via the Caco-2 assay

## Data Notation

**L0** - Compiled raw data files generated by the laboratory containing mass spectrometry results 

**L1** - L0 data with standardized column names 

**L2** - L1 data with added "Verification" column 

**L3** - Frequentist point estimates of desired chemical-specific toxicokinetic (TK) parameters 

**L4** - Bayesian estimates of desired chemical-specific toxicokinetic (TK) parameters

## Function Notation

In the function notations, "\<assay\>" can be replaced with the following:

- "clint": intrinsic hepatic clearance $Cl_{int}$
- "fup_red": fraction unbound in plasma $f_{up}$ via Rapid Equilibrium Dialysis (RED)
- "fup_uc": fraction unbound in plasma $f_{up}$ via Ultracentrifugation (UC)
- "caco2": membrane permeability $P_{app}$ via the Caco-2 assay 

**build\_mydata\_\<assay\>** - function used to create data objects necessary for Bayesian modeling

- Note: Function only available for "clint", "fup_red", and "fup_uc"

**calc\_\<assay\>\_point** - function used to calculate frequentist estimates from L2 file

**calc_\<assay\>** - function used to calculate Bayesian estimates from L2 file

- Note: Bayesian estimates are only available for "clint", "fup_red", and "fup_uc"

**create_catalog** - function used to create catalog of raw data (L0) files to be merged with "merge_level0" function

**create_chem_table** - function used to create chemical ID mapping table

**create_method_table** - function used to create chemical analysis method mapping table from L1 or L2 file

**format_\<assay\>** - function used to create L1 file from L0 file

**Heaviside** - function used to calculate Heaviside step function at desired values  

**initfunction_\<assay\>** - function used to set initial values for Bayesian modeling

- Note: Function only available for "clint", "fup_red", and "fup_uc"

**merge_level0** - function used to compile many raw data (L0) files into a single comprehensive L0 file 

**plot_clint** - function used to plot response vs. time plot for Cl~int~ estimates 

**plot_fup_uc** - function used to plot response vs. sample type for f~up~ estimates collected used ultracentrifugation (UC)

**sample_verification** - function used to create L2 file from L1 file, i.e. add sample verification or exclusion criteria notes 

**summarize_table** - function used to summarize L2 files 

